# ape.cli

The `ape.cli` namespace is a collection of `click` extensions and reusable implementations, such as common arguments /
options for accounts, project file-paths, and generic utilities. Use these resources in plugins as well as in CLI-based
scripts.

## Arguments

```{eval-rst}
.. automodule:: ape.cli.arguments
    :members:
    :show-inheritance:
```

## Choices

```{eval-rst}
.. automodule:: ape.cli.choices
    :members:
    :show-inheritance:
```

## Commands

```{eval-rst}
.. automodule:: ape.cli.commands
    :members:
    :show-inheritance:
```

## Options

```{eval-rst}
.. automodule:: ape.cli.options
    :members:
    :show-inheritance:
```

## Parameter Types

```{eval-rst}
.. automodule:: ape.cli.paramtype
    :members:
    :show-inheritance:
```
